package com.factory.controller.web;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.factory.base.entity.aggregates.PageBean;
import com.factory.base.entity.aggregates.ResponseBean;
import com.factory.base.util.res.ResponseBeanBuilder;
import com.factory.web.entity.pm.OnsiteItem;
import com.factory.web.entity.pm.OnsiteWorkshop;
import com.factory.web.entity.pm.req.AddPmPlanReq;
import com.factory.web.entity.pm.req.EditPmPlanReq;
import com.factory.web.entity.pm.req.PmPlanPauseFlagReq;
import com.factory.web.entity.pm.req.SearchPmItemResultListReq;
import com.factory.web.entity.pm.req.SearchPmPlanListForPadReq;
import com.factory.web.entity.pm.req.SearchPmPlanListReq;
import com.factory.web.entity.pm.req.SearchPmPlanReq;
import com.factory.web.entity.pm.req.SearchWorkshopReq;
import com.factory.web.entity.pm.res.PmItemResultListRes;
import com.factory.web.entity.pm.res.PmPlanListForPadRes;
import com.factory.web.entity.pm.res.PmPlanListRes;
import com.factory.web.entity.pm.res.PmPlanRes;
import com.factory.web.service.pm.PreventMistakeService;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiOperationSupport;
import lombok.extern.slf4j.Slf4j;

/**
 * 防错计划
 *
 * @author wzy
 * @date 2021-07-09 12:00:00
 */
@Api(tags = "WEB - 防错")
@RestController
@RequestMapping("/benteler/pm")
@Slf4j
public class PreventMistakeController {
	@Autowired
	private PreventMistakeService preventMistakeService;

	@ApiOperation(value = "新建防错计划")
	@PostMapping("//addPmPlan")
	@ApiOperationSupport(order = 1)
	public ResponseBean addPmPlan(@RequestBody AddPmPlanReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.addPmPlan(req));
	}

	@ApiOperation(value = "防错计划列表")
	@ApiOperationSupport(order = 2)
	@PostMapping("/getPmPlanlist")
	public ResponseBean<PageBean<PmPlanListRes>> getPmPlanlist(@RequestBody SearchPmPlanListReq req) {
		return preventMistakeService.getPmPlanList(req);
	}
	
	@ApiOperation(value = "取得防错计划信息")
	@ApiOperationSupport(order = 3)
	@PostMapping("/getPmPlan")
	public ResponseBean<PmPlanRes> getPmPlan(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getPmPlan(req);
	}

	@ApiOperation(value = "禁用防错计划")
	@PostMapping("/disablePmPlan")
	@ApiOperationSupport(order = 4)
	public ResponseBean disablePmPlan(@RequestBody PmPlanPauseFlagReq req) {
		return preventMistakeService.disablePmPlan(req);
	}
	
	@ApiOperation(value = "取得工作站及站下巡检项目信息")
	@ApiOperationSupport(order = 5)
	@PostMapping("/getWorkshop")
	public ResponseBean<OnsiteWorkshop> getWorkshop(@RequestBody SearchWorkshopReq req) {
		return preventMistakeService.getWorkshop(req);
	}
	
	@ApiOperation(value = "修改防错计划")
	@PostMapping("/editPmPlan")
	@ApiOperationSupport(order = 6)
	public ResponseBean editPmPlan(@RequestBody EditPmPlanReq req) {
		return ResponseBeanBuilder.ok(preventMistakeService.editPmPlan(req));
	}

	@ApiOperation(value = "检查记录列表")
	@ApiOperationSupport(order = 7)
	@PostMapping("/getPmItemResultList")
	public ResponseBean<List<PmItemResultListRes>> getPmItemResultList(@RequestBody SearchPmItemResultListReq req) {
		return preventMistakeService.getPmItemResultList(req);
	}
	
	// TODO 详细页面-上方-计划审批通过时间（质量经理、产品经理）、每频次的检查人和检查时间。
	
	@ApiOperation(value = "取得Pad端防错计划列表")
	@ApiOperationSupport(order = 8)
	@PostMapping("/getPmPlanListForPad")
	public ResponseBean<List<PmPlanListForPadRes>> getPmPlanListForPad(@RequestBody SearchPmPlanListForPadReq req) {
		return preventMistakeService.getPmPlanListForPad(req);
	}
	
	@ApiOperation(value = "通过计划ID取得工作站列表")
	@ApiOperationSupport(order = 9)
	@PostMapping("/getWorkshopList")
	public ResponseBean<List<OnsiteWorkshop>> getWorkshopList(@RequestBody SearchPmPlanReq req) {
		return preventMistakeService.getWorkshopList(req);
	}
	
	@ApiOperation(value = "通过工作站ID取得巡检项目列表")
	@ApiOperationSupport(order = 9)
	@PostMapping("/getItemList")
	public ResponseBean<List<OnsiteItem>> getItemList(@RequestBody SearchWorkshopReq req) {
		return preventMistakeService.getItemList(req);
	}
}
